@@ -62,15 +62,15 @@ library(stpm)
 data <- simdata_cont(N=100, ystart = 80, a = -0.1, Q = 1e-06, mu0 = 1e-5, theta = 0.08, f1 = 80, f=80, b=1, dt=1, sd0=5)
 ans <- spm_continuous(dat=data,
                       a = -0.1,
-                      f1 = 80+runif(1,-5,5), 
-                      Q = 1.0e-6+runif(1,-1e-7,1e-7),
-                      f = 80+runif(1,-5,5),
+                      f1 = 82, 
+                      Q = 1.4e-6,
+                      f = 77,
                       b = 1,
-                      mu0 = 1.0e-5+runif(1,-1e-6,1e-6),
-                      theta = 0.08+runif(1,-1e-3,1e-3),
+                      mu0 = 1.6e-5,
+                      theta = 0.1,
                       stopifbound = FALSE, maxeval=300,
-                      lb=c(-0.12, 60, 0.6e-6, 60, 0.5, 0.6e-5, 0.06), 
-                      ub=c(-0.08, 140, 1.3e-06, 140, 1.5, 1.2e-5, 0.10),
+                      lb=c(-0.2, 60, 0.1e-6, 60, 0.1, 0.1e-5, 0.01), 
+                      ub=c(0, 140, 5e-06, 140, 3, 5e-5, 0.20),
                       algorithm="NLOPT_LN_NELDERMEAD")
 ans
 
@@ -87,13 +87,13 @@ data <- simdata_cont(N=100,
                      theta=0.08,
                      ystart = c(100,200), sd0=c(5, 10), dt=1)
 
-a.d <- matrix(c(-0.1+runif(1,-1e-2,1e-2),  0.001+runif(1,-1e-4,1e-4), 0.001+runif(1,-1e-4,1e-4), -0.1+runif(1,-1e-2,1e-2)), nrow = 2, ncol = 2, byrow = T)
-f1.d <- t(matrix(c(100+runif(1,-5,5), 200+runif(1,-5,5)), nrow = 2, ncol = 1, byrow = F))
-Q.d <- matrix(c(1e-06+runif(1,-1e-7,1e-7), 1e-7+runif(1,-1e-8,1e-8), 1e-7+runif(1,-1e-8,1e-8),  1e-06+runif(1,-1e-7,1e-7)), nrow = 2, ncol = 2, byrow = T)
-f.d <- t(matrix(c(100+runif(1,-5,5), 200+runif(1,-5,5)), nrow = 2, ncol = 1, byrow = F))
+a.d <- matrix(c(-0.15,  0.002, 0.002, -0.15), nrow = 2, ncol = 2, byrow = T)
+f1.d <- t(matrix(c(95, 195), nrow = 2, ncol = 1, byrow = F))
+Q.d <- matrix(c(1.2e-06, 1.2e-7, 1.2e-7,  1.2e-06), nrow = 2, ncol = 2, byrow = T)
+f.d <- t(matrix(c(105, 205), nrow = 2, ncol = 1, byrow = F))
 b.d <- matrix(c(1, 2), nrow = 2, ncol = 1, byrow = F)
-mu0.d <- 1e-4 + runif(1,-1e-5,1e-5)
-theta.d <- 0.08+ runif(1,-1e-4,1e-4)
+mu0.d <- 1.1e-4
+theta.d <- 0.07
 
 ans <- spm_continuous(dat=data,
                       a = a.d, 
@@ -104,13 +104,13 @@ ans <- spm_continuous(dat=data,
                       mu0 = mu0.d,
                       theta = theta.d,
                       maxeval=150,
-                      lb=c(-0.12, ifelse(a.d[2,1] > 0, a.d[2,1]-0.1*a.d[2,1], a.d[2,1]+0.1*a.d[2,1]), ifelse(a.d[1,2] > 0, a.d[1,2]-0.1*a.d[1,2], a.d[1,2]+0.1*a.d[1,2]), -0.12,  
-                           95, 195, 
-                           Q.d[1,1]-0.1*Q.d[1,1], ifelse(Q.d[2,1] > 0, Q.d[2,1]-0.1*Q.d[2,1], Q.d[2,1]+0.1*Q.d[2,1]), ifelse(Q.d[1,2] > 0, Q.d[1,2]-0.1*Q.d[1,2], Q.d[1,2]+0.1*Q.d[1,2]), Q.d[2,2]-0.1*Q.d[2,2],
-                           95, 195,
-                           0.5, 1.5,
-                           0.8e-4,
-                           0.06),
+                      lb=c(-0.5, ifelse(a.d[2,1] > 0, a.d[2,1]-0.5*a.d[2,1], a.d[2,1]+0.5*a.d[2,1]), ifelse(a.d[1,2] > 0, a.d[1,2]-0.5*a.d[1,2], a.d[1,2]+0.5*a.d[1,2]), -0.5,  
+                           80, 100, 
+                           Q.d[1,1]-0.5*Q.d[1,1], ifelse(Q.d[2,1] > 0, Q.d[2,1]-0.5*Q.d[2,1], Q.d[2,1]+0.5*Q.d[2,1]), ifelse(Q.d[1,2] > 0, Q.d[1,2]-0.5*Q.d[1,2], Q.d[1,2]+0.5*Q.d[1,2]), Q.d[2,2]-0.5*Q.d[2,2],
+                           80, 100,
+                           0.1, 0.5,
+                           0.1e-4,
+                           0.01),
                       ub=c(-0.08,  0.002,  0.002, -0.08,  
                            110, 220, 
                            Q.d[1,1]+0.1*Q.d[1,1], ifelse(Q.d[2,1] > 0, Q.d[2,1]+0.1*Q.d[2,1], Q.d[2,1]-0.1*Q.d[2,1]), ifelse(Q.d[1,2] > 0, Q.d[1,2]+0.1*Q.d[1,2], Q.d[1,2]-0.1*Q.d[1,2]), Q.d[2,2]+0.1*Q.d[2,2],
